@@ -8,7 +8,7 @@ sub new {
 	my ($class) = @_;
 	my $self = { $image => shift, @_ };
 
-	bless ($self, $class);
+	bless ($self, ref($class) || $class);
 }
 
 sub get {
